package com.iotechn.unimall.admin.api.market;


import com.iotechn.unimall.core.annotation.HttpMethod;
import com.iotechn.unimall.core.annotation.HttpOpenApi;
import com.iotechn.unimall.core.annotation.HttpParam;
import com.iotechn.unimall.core.annotation.HttpParamType;
import com.iotechn.unimall.core.annotation.param.NotNull;
import com.iotechn.unimall.core.exception.ServiceException;
import com.iotechn.unimall.data.domain.market.MarketReceivingAddress;
import com.iotechn.unimall.data.model.Page;
import java.util.Date;

/**
 * 收货地址Service接口
 * 
 * @author jlb
 * @date 2022-08-01
 */
@HttpOpenApi(group = "admin.unimall.marketReceivingAddress", description = "收货地址")
public interface IMarketReceivingAddressService{
	@HttpMethod(description = "新增", permission = "admin:unimall:marketReceivingAddress:add", permissionParentName = "宠物管理", permissionName = "收货地址管理")
	public Boolean add(@NotNull @HttpParam(name = "marketReceivingAddress", type = HttpParamType.COMMON, description = "收货地址") MarketReceivingAddress marketReceivingAddress,
						   @HttpParam(name = "adminId", type = HttpParamType.ADMIN_ID, description = "adminId") Long adminId)throws ServiceException;

	@HttpMethod(description = "列表", permission = "admin:unimall:marketReceivingAddress:list",permissionParentName = "宠物管理", permissionName = "收货地址管理")
	public Page<MarketReceivingAddress> list(
								@HttpParam(name = "companyId", type = HttpParamType.COMMON, description = "") Long companyId,
							@HttpParam(name = "cusId", type = HttpParamType.COMMON, description = "客户id") String cusId,
							@HttpParam(name = "consigneeName", type = HttpParamType.COMMON, description = "收货人姓名") String consigneeName,
							@HttpParam(name = "phone", type = HttpParamType.COMMON, description = "手机号") String phone,
							@HttpParam(name = "location", type = HttpParamType.COMMON, description = "所在地区") String location,
							@HttpParam(name = "address", type = HttpParamType.COMMON, description = "详细地址") String address,
							@HttpParam(name = "status", type = HttpParamType.COMMON, description = "状态") String status,
							@HttpParam(name = "deleteFlag", type = HttpParamType.COMMON, description = "0：否（默认） 1：是") Integer deleteFlag,
							@HttpParam(name = "gmtCreate", type = HttpParamType.COMMON, description = "") Date gmtCreate,
							@HttpParam(name = "gmtUpdate", type = HttpParamType.COMMON, description = "") Date gmtUpdate,
							@HttpParam(name = "userId", type = HttpParamType.COMMON, description = "") Long userId,
							@HttpParam(name = "adminId", type = HttpParamType.COMMON, description = "") Long adminId,
					@HttpParam(name = "page", type = HttpParamType.COMMON, description = "页码", valueDef = "1") Integer page,
		@HttpParam(name = "limit", type = HttpParamType.COMMON, description = "页码长度", valueDef = "20") Integer limit)
		throws ServiceException;

	@HttpMethod(description = "删除", permission = "admin:unimall:marketReceivingAddress:delete",permissionParentName = "宠物管理", permissionName = "收货地址管理")
	public Boolean delete(@NotNull @HttpParam(name = "id", type = HttpParamType.COMMON, description = "")String id)throws ServiceException;

	@HttpMethod(description = "修改", permission = "admin:unimall:marketReceivingAddress:update",permissionParentName = "宠物管理", permissionName = "收货地址管理")
	public Boolean update(@NotNull @HttpParam(name = "marketReceivingAddress", type = HttpParamType.COMMON, description = "收货地址") MarketReceivingAddress marketReceivingAddress,
						  @HttpParam(name = "adminId", type = HttpParamType.ADMIN_ID, description = "adminId") Long adminId)throws ServiceException;

	@HttpMethod(description = "查询", permission = "admin:unimall:marketReceivingAddress:get",permissionParentName = "宠物管理", permissionName = "收货地址管理")
	public MarketReceivingAddress get(@NotNull @HttpParam(name = "id", type = HttpParamType.COMMON, description = "")Long id)throws ServiceException;
	
	@HttpMethod(description = "导出excl表", permission = "admin:unimall:marketReceivingAddress:export",permissionParentName = "宠物管理", permissionName = "收货地址管理")
	public String export(
								@HttpParam(name = "companyId", type = HttpParamType.COMMON, description = "") Long companyId,
							@HttpParam(name = "cusId", type = HttpParamType.COMMON, description = "客户id") String cusId,
							@HttpParam(name = "consigneeName", type = HttpParamType.COMMON, description = "收货人姓名") String consigneeName,
							@HttpParam(name = "phone", type = HttpParamType.COMMON, description = "手机号") String phone,
							@HttpParam(name = "location", type = HttpParamType.COMMON, description = "所在地区") String location,
							@HttpParam(name = "address", type = HttpParamType.COMMON, description = "详细地址") String address,
							@HttpParam(name = "status", type = HttpParamType.COMMON, description = "状态") String status,
							@HttpParam(name = "deleteFlag", type = HttpParamType.COMMON, description = "0：否（默认） 1：是") Integer deleteFlag,
							@HttpParam(name = "gmtCreate", type = HttpParamType.COMMON, description = "") Date gmtCreate,
							@HttpParam(name = "gmtUpdate", type = HttpParamType.COMMON, description = "") Date gmtUpdate,
							@HttpParam(name = "userId", type = HttpParamType.COMMON, description = "") Long userId,
							@HttpParam(name = "adminId", type = HttpParamType.COMMON, description = "") Long adminId,
				@HttpParam(name = "page", type = HttpParamType.COMMON, description = "页码", valueDef = "1") Integer page,
	@HttpParam(name = "limit", type = HttpParamType.COMMON, description = "页码长度", valueDef = "20") Integer limit)throws ServiceException;
	
}
